Text tile, to be used with `Deco Layout Editor`_.

.. contents::


This is initial release of Text Tile and is incomplete, but it is included in
first release of Deco, just to work on tiles api on which other tiles will be
based.

Please report issues in `Deco's issue tracker`_


Changelog
=========

1.0 (2012-06-22)
----------------

- initial release.
  [garbas]


.. _`Deco Layout Editor`: http://pypi.python.org/pypi/plone.app.deco
.. _`Deco's issue tracker`: http://pypi.python.org/pypi/plone.app.deco/issues
